@@ -34,7 +34,7 @@ HOUSE_NO_EXP4 = "((?:^|,|^.+ )((\d{1,3})[/ ]\d{1,3})[ ,]+)\w"
 HOUSE_NO_EXP5 = "((?:^|,|^.+ )(?:No(?:\.|\. | ))?(\d{1,4})[ ,]+)\w"
 VILLAGE_EXP = "(?i)(?:^|,| )(?:หมู่ที่|หมู่ที่|หมู่|ม .|ม.|Moo|Mu)\s?(\d+)"
 ROAD_EXP1 = "(?i)(?:^|,| )(?:(Soi [A-Za-z\- ]+(?: \d{1,4})?)|((?:ซอย|ถนน) [^ ]+(?: \d{1,4})?)|((?:ถ |ถ|ชบ)\.[^ ]+(?: \d{1,4})?))(?: |,|$)"
-ROAD_EXP2 = "(?i)(?:^|(?:[^A-Za-z\-\. ]))([A-Za-z\-\. ]+ (?:\d{1,4} )?(?:Soi|Road|Raod|Rd\.?|Highway|Route|Alley|Avenue|Ave\.?)(?: \d{1,4})?)(?: |,|$)"
+ROAD_EXP2 = "(?i)(?:^|(?:[^A-Za-z\-\. ]))([A-Za-z\-\. ]+ (?:\d{1,4} )?(?:Soi|Road|Raod|Rd\.?|Highway|Route|Alley|Avenue|Ave\.?|Street|St\.?|Drive|Dr\.?|Central|Circuit|Close|Crescent|Circle|Way|Lane|Ln\.?|Link|Loop|Sector|Walk|Industrial Estate|Industry Estate|Estate|Industrial Park|Industry Park|Park)(?: \d{1,4})?)(?: |,|$)"
 
 
 def load_thai_admin_areas(dir_path):
